@@ -224,7 +224,7 @@ def create_mobile(root):
 
     default_level_second_last_row = default_level["rows"][len(default_level["rows"]) - 2]
     default_level_last_row = default_level["rows"][len(default_level["rows"]) - 1]
-    
+
     if len(default_level["rows"][0]) == 12: # Thai, Lao, Khmer
         pass
     elif len(default_level["rows"][0]) == 11:
@@ -260,36 +260,36 @@ def create_mobile(root):
 
     if (uppercase_level):
         if len(default_level_second_last_row) == 9: # Macedonian, Kirghiz, Russian, Belarusian, Serbian, Ukrainian, Mongolian
-            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="keyboard-shift-symbolic", width=1))
-            default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1))
+            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="osk-shift-symbolic", width=1))
+            default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1))
         elif len(default_level_second_last_row) == 8: # Bulgarian
-            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="keyboard-shift-symbolic", width=1.5))
-            default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="osk-shift-symbolic", width=1.5))
+            default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
         elif len(default_level_second_last_row) == 7:
-            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="keyboard-shift-symbolic", width=1.5))
-            default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+            default_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="shift", iconName="osk-shift-symbolic", width=1.5))
+            default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
         else:
             raise KeyError("Found %d keys in second last row with uppercase level: %s" %(len(default_level_second_last_row), root["name"]))
     else:
         if len(default_level_second_last_row) == 10: # Thai, Persian, Arabic, Lao, Khmer
             if len(default_level["rows"][1]) == 12: # Thai, Lao, Khmer
-                default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.75, leftOffset=0.25))
+                default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.75, leftOffset=0.25))
             elif len(default_level["rows"][1]) == 11: # Persian, Arabic
-                default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic"))
+                default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic"))
             else:
                 raise KeyError("Found %d keys in second row without uppercase level: %s" %(len(default_level["rows"][1]), root["name"]))
         elif len(default_level_second_last_row) == 9: # Hindi, Hebrew
             if len(default_level["rows"][1]) == 11: # Hindi
                 default_level_second_last_row[0]["leftOffset"] = 1
-                default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic"))
+                default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic"))
             elif len(default_level["rows"][1]) == 10: # Hebrew
-                default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1))
+                default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1))
             else:
                 raise KeyError("Found %d keys in second row without uppercase level: %s" %(len(default_level["rows"][1]), root["name"]))
 
         elif len(default_level_second_last_row) == 7: # Georgian
             default_level_second_last_row[0]["leftOffset"] = 1.5
-            default_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.25, leftOffset=0.25))
+            default_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.25, leftOffset=0.25))
         else:
             raise KeyError("Found %d keys in second last row without uppercase level: %s" %(len(default_level_second_last_row), root["name"]))
 
@@ -297,8 +297,8 @@ def create_mobile(root):
     default_level_last_row.insert(0, create_action_key(action="levelSwitch", level="opt", label="123", width=1.5))
     default_level_last_row.insert(1, create_action_key(action="emoji", iconName="smile-symbolic"))
     default_level_last_row[3] = create_char_key(strings=[" "], width=3)
-    default_level_last_row.append(create_action_key(action="languageMenu", iconName="keyboard-layout-symbolic"))
-    default_level_last_row.append(create_char_key(keyval="0xff0d", iconName="keyboard-enter-symbolic", width=1.5))
+    default_level_last_row.append(create_action_key(action="languageMenu", iconName="osk-layout-symbolic"))
+    default_level_last_row.append(create_char_key(keyval="0xff0d", iconName="osk-enter-symbolic", width=1.5))
 
     if (uppercase_level):
         uppercase_level_second_last_row = uppercase_level["rows"][len(uppercase_level["rows"]) - 2]
@@ -322,25 +322,25 @@ def create_mobile(root):
             raise KeyError("Found %d keys in uppercase level second row: %s" %(len(default_level["rows"][1]), root["name"]))
 
         if len(uppercase_level_second_last_row) == 9: # Macedonian, Kirghiz, Russian, Belarusian, Serbian, Ukrainian, Mongolian
-            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="keyboard-shift-symbolic", width=1))
-            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1))
+            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="osk-shift-symbolic", width=1))
+            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1))
         elif len(uppercase_level_second_last_row) == 8: # Bulgarian
-            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="keyboard-shift-symbolic", width=1.5))
-            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="osk-shift-symbolic", width=1.5))
+            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
         elif len(uppercase_level_second_last_row) == 7:
-            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="keyboard-shift-symbolic", width=1.5))
-            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+            uppercase_level_second_last_row.insert(0, create_action_key(action="levelSwitch", level="default", iconName="osk-shift-symbolic", width=1.5))
+            uppercase_level_second_last_row.append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
         else:
             raise KeyError("Found %d keys in uppercase level second last row: %s" %(len(uppercase_level_second_last_row), root["name"]))
 
         uppercase_level_last_row.insert(0, create_action_key(action="levelSwitch", level="opt", label="123", width=1.5))
         uppercase_level_last_row.insert(1, create_action_key(action="emoji", iconName="smile-symbolic"))
         uppercase_level_last_row[3] = create_char_key(strings=[" "], width=3)
-        uppercase_level_last_row.append(create_action_key(action="languageMenu", iconName="keyboard-layout-symbolic"))
-        uppercase_level_last_row.append(create_char_key(keyval="0xff0d", iconName="keyboard-enter-symbolic", width=1.5))
+        uppercase_level_last_row.append(create_action_key(action="languageMenu", iconName="osk-layout-symbolic"))
+        uppercase_level_last_row.append(create_char_key(keyval="0xff0d", iconName="osk-enter-symbolic", width=1.5))
 
     optkeys_level["rows"][2].insert(0, create_action_key(action="levelSwitch", level="opt+shift", label="=/<", width=1.5))
-    optkeys_level["rows"][2].append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+    optkeys_level["rows"][2].append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
 
     # Remove ° so that - in opt can be _ in opt+shift
     degree_key = optshiftkeys_level["rows"][1][5];
@@ -353,15 +353,15 @@ def create_mobile(root):
     optkeys_level["rows"][3].insert(1, create_action_key(action="emoji", iconName="smile-symbolic"))
     optkeys_level["rows"][3].pop(2)
     optkeys_level["rows"][3].insert(3, create_char_key(strings=[" "], width=3))
-    optkeys_level["rows"][3].append(create_action_key(action="languageMenu", iconName="keyboard-layout-symbolic"))
-    optkeys_level["rows"][3].append(create_char_key(keyval="0xff0d", iconName="keyboard-enter-symbolic", width=1.5))
+    optkeys_level["rows"][3].append(create_action_key(action="languageMenu", iconName="osk-layout-symbolic"))
+    optkeys_level["rows"][3].append(create_char_key(keyval="0xff0d", iconName="osk-enter-symbolic", width=1.5))
 
     # Move \ to last free entry in 2nd row
     optshiftkeys_level["rows"][1].append(optshiftkeys_level["rows"][2].pop(0))
 
     optshiftkeys_level["rows"][2].insert(0, degree_key);
     optshiftkeys_level["rows"][2].insert(0, create_action_key(action="levelSwitch", level="opt", label="123", width=1.5))
-    optshiftkeys_level["rows"][2].append(create_action_key(action="delete", iconName="edit-clear-symbolic", width=1.5))
+    optshiftkeys_level["rows"][2].append(create_action_key(action="delete", iconName="osk-delete-symbolic", width=1.5))
 
     optshiftkeys_level["rows"][3].pop(3)
     optshiftkeys_level["rows"][3].pop(3)
@@ -369,8 +369,8 @@ def create_mobile(root):
     optshiftkeys_level["rows"][3].insert(1, create_action_key(action="emoji", iconName="smile-symbolic"))
     optshiftkeys_level["rows"][3].pop(4)
     optshiftkeys_level["rows"][3].insert(3, create_char_key(strings=[" "], width=3))
-    optshiftkeys_level["rows"][3].append(create_action_key(action="languageMenu", iconName="keyboard-layout-symbolic"))
-    optshiftkeys_level["rows"][3].append(create_char_key(keyval="0xff0d", iconName="keyboard-enter-symbolic", width=1.5))
+    optshiftkeys_level["rows"][3].append(create_action_key(action="languageMenu", iconName="osk-layout-symbolic"))
+    optshiftkeys_level["rows"][3].append(create_char_key(keyval="0xff0d", iconName="osk-enter-symbolic", width=1.5))
 
     return root
 
