@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -238,7 +236,7 @@ export const AuthPrompt = GObject.registerClass({
     _init(gdmClient, mode) {
         super._init({
             style_class: 'login-dialog-prompt-layout',
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             x_expand: true,
             x_align: Clutter.ActorAlign.CENTER,
             reactive: true,
@@ -259,7 +257,7 @@ export const AuthPrompt = GObject.registerClass({
         else if (this._mode === AuthPromptMode.UNLOCK_OR_LOG_IN)
             reauthenticationOnly = false;
 
-        this._userVerifier = new GdmUtil.ShellUserVerifier(this._gdmClient, {reauthenticationOnly});
+        this._userVerifier = this._createUserVerifier(this._gdmClient, {reauthenticationOnly});
 
         this._userVerifier.connect('ask-question', this._onAskQuestion.bind(this));
         this._userVerifier.connect('show-message', this._onShowMessage.bind(this));
@@ -310,6 +308,10 @@ visible:false,
         this.add_child(this._message);
     }
 
+    _createUserVerifier(gdmClient, params) {
+        return new GdmUtil.ShellUserVerifier(gdmClient, params);
+    }
+
     _onDestroy() {
         this._inactiveEntry.destroy();
         this._inactiveEntry = null;
@@ -320,7 +322,7 @@ visible:false,
     _initInputRow() {
         this._mainBox = new St.BoxLayout({
             style_class: 'login-dialog-button-box',
-            vertical: false,
+            orientation: Clutter.Orientation.HORIZONTAL,
         });
         this.add_child(this._mainBox);
 
@@ -343,6 +345,8 @@ visible:false,
         this._authList = new AuthList.AuthList();
         this._authList.set({
             visible: false,
+            x_align: Clutter.ActorAlign.FILL,
+            x_expand: true,
         });
         this._authList.connect('activate', (list, key) => {
             this._authList.reactive = false;
