@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -7,19 +5,14 @@ import GObject from 'gi://GObject';
 import Shell from 'gi://Shell';
 import St from 'gi://St';
 
-import * as Main from './main.js';
 import * as MessageList from './messageList.js';
-import * as MessageTray from './messageTray.js';
-import * as Mpris from './mpris.js';
 import * as PopupMenu from './popupMenu.js';
 import {ensureActorVisibleInScrollView} from '../misc/animationUtils.js';
-import * as Params from '../misc/params.js';
 
 import {formatDateWithCFormatString} from '../misc/dateUtils.js';
 import {loadInterfaceXML} from '../misc/fileUtils.js';
 
 const SHOW_WEEKDATE_KEY = 'show-weekdate';
-const MAX_NOTIFICATION_BUTTONS = 3;
 
 const NC_ = (context, str) => `${context}\u0004${str}`;
 
@@ -98,11 +91,11 @@ export const EventSourceBase = GObject.registerClass({
     GTypeFlags: GObject.TypeFlags.ABSTRACT,
     Properties: {
         'has-calendars': GObject.ParamSpec.boolean(
-            'has-calendars', 'has-calendars', 'has-calendars',
+            'has-calendars', null, null,
             GObject.ParamFlags.READABLE,
             false),
         'is-loading': GObject.ParamSpec.boolean(
-            'is-loading', 'is-loading', 'is-loading',
+            'is-loading', null, null,
             GObject.ParamFlags.READABLE,
             false),
     },
@@ -766,195 +759,13 @@ export const Calendar = GObject.registerClass({
     }
 });
 
-export const NotificationMessage = GObject.registerClass(
-class NotificationMessage extends MessageList.Message {
-    constructor(notification) {
-        super(notification.source);
-
-        this.notification = notification;
-
-        this.connect('close', () => {
-            this._closed = true;
-            if (this.notification)
-                this.notification.destroy(MessageTray.NotificationDestroyedReason.DISMISSED);
-        });
-        notification.connectObject(
-            'action-added', (_, action) => this._addAction(action),
-            'action-removed', (_, action) => this._removeAction(action),
-            'destroy', () => {
-                this.notification = null;
-                if (!this._closed)
-                    this.close();
-            }, this);
-
-        notification.bind_property('title',
-            this, 'title',
-            GObject.BindingFlags.SYNC_CREATE);
-        notification.bind_property('body',
-            this, 'body',
-            GObject.BindingFlags.SYNC_CREATE);
-        notification.bind_property('use-body-markup',
-            this, 'use-body-markup',
-            GObject.BindingFlags.SYNC_CREATE);
-        notification.bind_property('datetime',
-            this, 'datetime',
-            GObject.BindingFlags.SYNC_CREATE);
-        notification.bind_property('gicon',
-            this, 'icon',
-            GObject.BindingFlags.SYNC_CREATE);
-
-        this._actions = new Map();
-        this.notification.actions.forEach(action => {
-            this._addAction(action);
-        });
-    }
-
-    vfunc_clicked() {
-        this.notification.activate();
-    }
-
-    canClose() {
-        return true;
-    }
-
-    canHide() {
-        return this.has_style_class_name('notification-banner');
-    }
-
-    _addAction(action) {
-        if (!this._buttonBox) {
-            this._buttonBox = new St.BoxLayout({
-                x_expand: true,
-                style_class: 'notification-buttons-bin',
-            });
-            this.setActionArea(this._buttonBox);
-            global.focus_manager.add_group(this._buttonBox);
-        }
-
-        if (this._buttonBox.get_n_children() >= MAX_NOTIFICATION_BUTTONS)
-            return;
-
-        const button = new St.Button({
-            style_class: 'notification-button',
-            x_expand: true,
-            label: action.label,
-        });
-
-        button.connect('clicked', () => action.activate());
-
-        this._actions.set(action, button);
-        this._buttonBox.add_child(button);
-    }
-
-    _removeAction(action) {
-        this._actions.get(action)?.destroy();
-        this._actions.delete(action);
-    }
-});
-
-const NotificationSection = GObject.registerClass(
-class NotificationSection extends MessageList.MessageListSection {
-    _init(params) {
-        super._init();
-
-        params = Params.parse(params, {
-            isOnLockscreen: false,
-        });
-
-        this._isOnLockscreen = params.isOnLockscreen;
-        this._nUrgent = 0;
-
-        Main.messageTray.connectObject('source-added',
-            this._sourceAdded.bind(this), this);
-        Main.messageTray.getSources().forEach(source => {
-            this._sourceAdded(Main.messageTray, source);
-        });
-    }
-
-    get allowed() {
-        if (Main.sessionMode.isLocked && !this._isOnLockscreen)
-            return false;
-
-        return Main.sessionMode.hasNotifications &&
-               !Main.sessionMode.isGreeter;
-    }
-
-    _updateMessageDetailsLockscreen(message, source) {
-        const show = source.policy.showInLockScreen;
-        const showDetails = source.policy.detailsInLockScreen ||
-            source.narrowestPrivacyScope === MessageTray.PrivacyScope.SYSTEM;
-
-        if (show)
-            message.show();
-        else
-            message.hide();
-
-        message.setShowDetails(showDetails);
-    }
-
-    _sourceAdded(tray, source) {
-        const policyChangedId = source.policy.connect('notify', () => {
-            if (!this._isOnLockscreen)
-                return;
-
-            for (const m of this._messages)
-                this._updateMessageDetailsLockscreen(m, source);
-        });
-
-        source.connectObject(
-            'notification-added', this._onNotificationAdded.bind(this),
-            'destroy', () => source.policy.disconnect(policyChangedId),
-            this);
-
-        for (const n of source.notifications)
-            this._onNotificationAdded(source, n);
-    }
-
-    _onNotificationAdded(source, notification) {
-        let message = new NotificationMessage(notification);
-
-        if (this._isOnLockscreen)
-            this._updateMessageDetailsLockscreen(message, source);
-
-        let isUrgent = notification.urgency === MessageTray.Urgency.CRITICAL;
-
-        notification.connectObject(
-            'destroy', () => {
-                if (isUrgent)
-                    this._nUrgent--;
-            },
-            'notify::datetime', () => {
-                // The datetime property changes whenever the notification is updated
-                this.moveMessage(message, isUrgent ? 0 : this._nUrgent, this.mapped);
-            }, this);
-
-        if (isUrgent) {
-            // Keep track of urgent notifications to keep them on top
-            this._nUrgent++;
-        } else if (this.mapped) {
-            // Only acknowledge non-urgent notifications in case it
-            // has important actions that are inaccessible when not
-            // shown as banner
-            notification.acknowledged = true;
-        }
-
-        let index = isUrgent ? 0 : this._nUrgent;
-        this.addMessageAtIndex(message, index, this.mapped);
-    }
-
-    vfunc_map() {
-        this._messages.forEach(message => {
-            if (message.notification.urgency !== MessageTray.Urgency.CRITICAL)
-                message.notification.acknowledged = true;
-        });
-        super.vfunc_map();
-    }
-});
-
 const Placeholder = GObject.registerClass(
 class Placeholder extends St.BoxLayout {
     _init() {
-        super._init({style_class: 'message-list-placeholder', vertical: true});
+        super._init({
+            style_class: 'message-list-placeholder',
+            orientation: Clutter.Orientation.VERTICAL,
+        });
         this._date = new Date();
 
         this._icon = new St.Icon({icon_name: 'no-notifications-symbolic'});
@@ -987,17 +798,19 @@ class DoNotDisturbSwitch extends PopupMenu.Switch {
 
 export const CalendarMessageList = GObject.registerClass(
 class CalendarMessageList extends St.Widget {
-    _init(notificationsParams) {
-        super._init({
+    constructor(messageViewParams) {
+        super({
             style_class: 'message-list',
             layout_manager: new Clutter.BinLayout(),
             x_expand: true,
             y_expand: true,
         });
 
+        this._messageView = new MessageList.MessageView(messageViewParams);
+
         this._scrollView = new St.ScrollView({
-            style_class: 'vfade',
             x_expand: true, y_expand: true,
+            child: this._messageView,
         });
         this._scrollView.set_policy(St.PolicyType.NEVER, St.PolicyType.EXTERNAL);
 
@@ -1008,28 +821,34 @@ class CalendarMessageList extends St.Widget {
 
         this.add_child(this._scrollView);
 
-        this._sectionList = new St.BoxLayout({
-            style_class: 'message-list-sections',
-            vertical: true,
-            x_expand: true,
-            y_expand: true,
-        });
-        this._scrollView.child = this._sectionList;
-
-        this._mediaSection = new Mpris.MediaSection();
-        this._addSection(this._mediaSection);
-
-        this._notificationSection = new NotificationSection(notificationsParams);
-        this._addSection(this._notificationSection);
-    }
-
-    _addSection(section) {
-        section.connectObject(
-            'destroy', () => this._sectionList.remove_child(section),
+        this._messageView.connectObject(
             'message-focused', (_s, messageActor) => {
                 ensureActorVisibleInScrollView(this._scrollView, messageActor);
             }, this);
-        this._sectionList.add_child(section);
+    }
+
+    maybeCollapseMessageGroupForEvent(event) {
+        if (!this._messageView.expandedGroup)
+            return Clutter.EVENT_PROPAGATE;
+
+        if (event.type() === Clutter.EventType.KEY_PRESS &&
+            event.get_key_symbol() === Clutter.KEY_Escape) {
+            this._messageView.collapse();
+            return Clutter.EVENT_STOP;
+        }
+
+        const targetActor = global.stage.get_event_actor(event);
+        const onScrollbar =
+            this._scrollView.contains(targetActor) &&
+            !this._messageView.contains(targetActor);
+
+        if ((event.type() === Clutter.EventType.BUTTON_PRESS ||
+            event.type() === Clutter.EventType.TOUCH_BEGIN) &&
+            !this._messageView.expandedGroup.contains(targetActor) &&
+            !onScrollbar)
+            this._messageView.collapse();
+
+        return Clutter.EVENT_PROPAGATE;
     }
 
     _panMayRecognize(gesture) {
@@ -1039,7 +858,7 @@ class CalendarMessageList extends St.Widget {
 
         const coords = gesture.get_centroid_abs();
         const delta = coords.y - beginCoords.y;
-        const adj = this._scrollView.vscroll.adjustment;
+        const adj = this._scrollView.vadjustment;
 
         // When panning upwards while the adjustment is at the end (scrolled
         // all the way to bottom) let other gestures win.
@@ -1052,8 +871,10 @@ class CalendarMessageList extends St.Widget {
         return true;
     }
 
-    _onPanUpdate(action, deltaX, deltaY, totalDistance) {
-        let adjustment = this._scrollView.vscroll.adjustment;
-        adjustment.value -= (deltaY / this.height) * adjustment.page_size;
+    _onPanUpdate(gesture) {
+        const [latestDeltaVec] = gesture.get_delta();
+
+        let adjustment = this._scrollView.vadjustment;
+        adjustment.value -= (latestDeltaVec.get_y() / this.height) * adjustment.page_size;
     }
 });
