@@ -1,11 +1,7 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import GLib from 'gi://GLib';
-import GObject from 'gi://GObject';
 import Meta from 'gi://Meta';
 import Shell from 'gi://Shell';
-import St from 'gi://St';
 import * as Signals from '../misc/signals.js';
 
 import * as Main from './main.js';
@@ -27,9 +23,9 @@ export const DragMotionResult = {
 };
 
 const DRAG_CURSOR_MAP = {
-    0: Meta.Cursor.DND_UNSUPPORTED_TARGET,
-    1: Meta.Cursor.DND_COPY,
-    2: Meta.Cursor.DND_MOVE,
+    0: Meta.Cursor.NO_DROP,
+    1: Meta.Cursor.COPY,
+    2: Meta.Cursor.MOVE,
 };
 
 export const DragDropResult = {
@@ -88,38 +84,9 @@ export function removeDragMonitor(monitor) {
     }
 }
 
-/**
- * DndGesture:
- * @params: (optional) Additional parameters
- *
- * A sub-class of ClutterGesture that allows dragging actors.
- *
- * If %manualMode is %true in @params, do not automatically start
- * drag and drop on click. The drag has to be started by calling
- * startDrag() instead.
- *
- * If %restoreOnSuccess is %true in @params, the drag actor will be
- * faded back in at its initial position after a successful drag.
- *
- * If %dragActorMaxSize is present in @params, the drag actor will
- * be scaled down to be no larger than that size in pixels.
- *
- * If %dragActorOpacity is present in @params, the drag actor will
- * be set to have that opacity during the drag.
- *
- * Note that when the drag actor is the source actor and the drop
- * succeeds, the actor scale and opacity aren't reset; if the drop
- * target wants to reuse the actor, it's up to the drop target to
- * reset these values.
- */
-export const DndGesture = GObject.registerClass({
-    Signals: {
-        'drag-begin':  {param_types: [GObject.TYPE_UINT]},
-        'drag-end': {param_types: [GObject.TYPE_UINT, Clutter.Actor.$gtype]},
-        'drag-cancelled': {param_types: [GObject.TYPE_UINT]},
-    },
-}, class DndGesture extends Clutter.Gesture {
-    _init(params) {
+class _Draggable extends Signals.EventEmitter {
+    constructor(actor, params) {
+        super();
         params = Params.parse(params, {
             manualMode: false,
             timeoutThreshold: 0,
@@ -128,6 +95,16 @@ export const DndGesture = GObject.registerClass({
             dragActorOpacity: undefined,
         });
 
+        this.actor = actor;
+
+        this._dndGesture = new Shell.DndStartGesture({
+            manual_mode: params.manualMode,
+            timeout_threshold: params.timeoutThreshold,
+        });
+        this._dndGesture.connect('recognize', () => this._gestureRecognized());
+
+        this.actor.add_action(this._dndGesture);
+
         this._restoreOnSuccess = params.restoreOnSuccess;
         this._dragActorMaxSize = params.dragActorMaxSize;
         this._dragActorOpacity = params.dragActorOpacity;
@@ -135,8 +112,6 @@ export const DndGesture = GObject.registerClass({
 
         this._animationInProgress = false; // The drag is over and the item is in the process of animating to its original position (snapping back or reverting).
         this._dragCancellable = true;
-
-        super._init();
     }
 
     _grabEvents(device, touchSequence) {
@@ -158,36 +133,32 @@ export const DndGesture = GObject.registerClass({
         this._grabbedEventSequence = null;
     }
 
-    vfunc_set_actor(actor) {
-        if (this.state === Clutter.GestureState.RECOGNIZING && this._dragCancellable)
-            this.set_state(Clutter.GestureState.CANCELLED);
-
-        super.vfunc_set_actor(actor);
-        this._actor = actor;
-    }
-
     _gestureRecognized() {
-        const [stageX, stageY] = this._startingEvent.get_coords();
-        const device = this._startingEvent.get_device();
-        const sequence = this._startingEvent.get_event_sequence();
-        const time = this._startingEvent.get_time();
-        delete this._startingEvent;
+        const pointBeginEvent = this._dndGesture.get_point_begin_event();
+        [this._dragStartX, this._dragStartY] = pointBeginEvent.get_coords();
+
+        const triggeringEvent = this._dndGesture.get_drag_triggering_event();
+        const [stageX, stageY] = triggeringEvent.get_coords();
+        const device = triggeringEvent.get_device();
+        const sequence = triggeringEvent.get_event_sequence();
+        const time = triggeringEvent.get_time();
 
         currentDraggable = this;
+
         this._grabEvents(device, sequence);
         if (!this._grab)
             return;
 
         this.emit('drag-begin', time);
-        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.NO_DROP);
 
         this._dragX = stageX;
         this._dragY = stageY;
 
         let scaledWidth, scaledHeight;
 
-        if (this._actor._delegate && this._actor._delegate.getDragActor) {
-            this._dragActor = this._actor._delegate.getDragActor();
+        if (this.actor._delegate && this.actor._delegate.getDragActor) {
+            this._dragActor = this.actor._delegate.getDragActor();
             Main.uiGroup.add_child(this._dragActor);
             Main.uiGroup.set_child_above_sibling(this._dragActor, null);
             Shell.util_set_hidden_from_pick(this._dragActor, true);
@@ -195,8 +166,8 @@ export const DndGesture = GObject.registerClass({
             // Drag actor does not always have to be the same as actor. For example drag actor
             // can be an image that's part of the actor. So to perform "snap back" correctly we need
             // to know what was the drag actor source.
-            if (this._actor._delegate.getDragActorSource) {
-                this._dragActorSource = this._actor._delegate.getDragActorSource();
+            if (this.actor._delegate.getDragActorSource) {
+                this._dragActorSource = this.actor._delegate.getDragActorSource();
                 // If the user dragged from the source, then position
                 // the dragActor over it. Otherwise, center it
                 // around the pointer
@@ -216,7 +187,7 @@ export const DndGesture = GObject.registerClass({
                     this._dragActorSource = null;
                 });
             } else {
-                this._dragActorSource = this._actor;
+                this._dragActorSource = this.actor;
             }
             this._dragOrigParent = undefined;
 
@@ -225,10 +196,10 @@ export const DndGesture = GObject.registerClass({
 
             [scaledWidth, scaledHeight] = this._dragActor.get_transformed_size();
         } else {
-            this._dragActor = this._actor;
+            this._dragActor = this.actor;
 
             this._dragActorSource = undefined;
-            this._dragOrigParent = this._actor.get_parent();
+            this._dragOrigParent = this.actor.get_parent();
 
             this._dragActorHadFixedPos = this._dragActor.fixed_position_set;
             this._dragOrigX = this._dragActor.allocation.x1;
@@ -248,8 +219,9 @@ export const DndGesture = GObject.registerClass({
             this._dragOffsetX = transformedExtents.origin.x - this._dragStartX;
             this._dragOffsetY = transformedExtents.origin.y - this._dragStartY;
 
-            scaledWidth = transformedExtents.size.width;
-            scaledHeight = transformedExtents.size.height;
+            scaledWidth = transformedExtents.get_width();
+            scaledHeight = transformedExtents.get_height();
+
             this._dragActor.scale_x = scaledWidth / this._dragOrigWidth;
             this._dragActor.scale_y = scaledHeight / this._dragOrigHeight;
 
@@ -321,27 +293,6 @@ export const DndGesture = GObject.registerClass({
         }
     }
 
-    /**
-     * Directly initiate a drag and drop operation from the given actor.
-     * This function is useful to call if you've specified manualMode
-     * for the draggable.
-     *
-     * @param {number} stageX - X coordinate of event
-     * @param {number} stageY - Y coordinate of event
-     * @param {number} time - Event timestamp
-     * @param {Clutter.EventSequence=} sequence - Event sequence
-     * @param {Clutter.InputDevice=} device - device that originated the event
-     */
-    startDrag(startingEvent = null) {
-        if (this.get_n_points() !== 1)
-            return;
-
-        if (this.state === Clutter.GestureState.POSSIBLE) {
-            this._startingEvent = startingEvent;
-            this.set_state(Clutter.GestureState.COMPLETED);
-        }
-    }
-
     _updateActorPosition(origScale, origDragOffsetX, origDragOffsetY, transX, transY) {
         const currentScale = this._dragActor.scale_x / origScale;
         this._dragOffsetX = currentScale * origDragOffsetX - transX;
@@ -351,33 +302,6 @@ export const DndGesture = GObject.registerClass({
             this._dragY + this._dragOffsetY);
     }
 
-    _maybeStartDrag(point) {
-        const coords = this.get_point_coords_abs(point);
-        const event = this.get_point_event(point);
-
-        if (this._dragThresholdIgnored)
-            return;
-
-        // See if the user has moved the mouse enough to trigger a drag
-        let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
-        let threshold = St.Settings.get().drag_threshold * scaleFactor;
-        if ((Math.abs(coords.x - this._dragStartX) > threshold ||
-             Math.abs(coords.y - this._dragStartY) > threshold)) {
-            const deviceType = event.get_source_device().get_device_type();
-            const isPointerOrTouchpad =
-                deviceType === Clutter.InputDeviceType.POINTER_DEVICE ||
-                deviceType === Clutter.InputDeviceType.TOUCHPAD_DEVICE;
-            const ellapsedTime = event.get_time() - this._dragStartTime;
-
-            // Pointer devices (e.g. mouse) start the drag immediately
-            if (isPointerOrTouchpad || ellapsedTime > this._dragTimeoutThreshold) {
-                this.startDrag(event);
-            } else {
-                this._dragThresholdIgnored = true;
-            }
-        }
-    }
-
     _pickTargetActor() {
         return this._dragActor.get_stage().get_actor_at_pos(
             Clutter.PickMode.ALL, this._dragX, this._dragY);
@@ -391,7 +315,7 @@ export const DndGesture = GObject.registerClass({
             x: this._dragX,
             y: this._dragY,
             dragActor: this._dragActor,
-            source: this._actor._delegate,
+            source: this.actor._delegate,
             targetActor: target,
         };
 
@@ -425,11 +349,12 @@ export const DndGesture = GObject.registerClass({
                 // We currently loop through all parents on drag-over even if one of the children has handled it.
                 // We can check the return value of the function and break the loop if it's true if we don't want
                 // to continue checking the parents.
-                let result = target._delegate.handleDragOver(this._actor._delegate,
-                                                             this._dragActor,
-                                                             targX,
-                                                             targY,
-                                                             0);
+                let result = target._delegate.handleDragOver(
+                    this.actor._delegate,
+                    this._dragActor,
+                    targX,
+                    targY,
+                    0);
                 if (result !== DragMotionResult.CONTINUE) {
                     global.display.set_cursor(DRAG_CURSOR_MAP[result]);
                     return GLib.SOURCE_REMOVE;
@@ -437,7 +362,7 @@ export const DndGesture = GObject.registerClass({
             }
             target = target.get_parent();
         }
-        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.NO_DROP);
         return GLib.SOURCE_REMOVE;
     }
 
@@ -499,7 +424,7 @@ export const DndGesture = GObject.registerClass({
                 let [r_, targX, targY] = target.transform_stage_point(dropX, dropY);
                 let accepted = false;
                 try {
-                    accepted = target._delegate.acceptDrop(this._actor._delegate,
+                    accepted = target._delegate.acceptDrop(this.actor._delegate,
                         this._dragActor, targX, targY, event.get_time());
                 } catch (e) {
                     // On error, skip this target
@@ -645,8 +570,8 @@ export const DndGesture = GObject.registerClass({
     }
 
     _onEvent(actor, event) {
-        if (event.type() == Clutter.EventType.KEY_PRESS) {
-            if (event.get_key_symbol() == Clutter.KEY_Escape)
+        if (event.type() === Clutter.EventType.KEY_PRESS) {
+            if (event.get_key_symbol() === Clutter.KEY_Escape)
                 this._cancelDrag(event.get_time());
 
             return Clutter.EVENT_PROPAGATE;
@@ -671,47 +596,6 @@ export const DndGesture = GObject.registerClass({
         return Clutter.EVENT_PROPAGATE;
     }
 
-    vfunc_should_handle_sequence(sequenceBeginEvent) {
-        const eventType = sequenceBeginEvent.type();
-
-        return eventType === Clutter.EventType.BUTTON_PRESS ||
-               eventType === Clutter.EventType.TOUCH_BEGIN;
-    }
-
-    vfunc_point_began(point) {
-        const event = this.get_point_event(point);
-        const beginCoords = this.get_point_begin_coords_abs(point);
-
-        if (this.get_n_points() > 1) {
-            this.set_state(Clutter.GestureState.CANCELLED);
-            return;
-        }
-
-        this._dragStartTime = event.get_time();
-        this._dragThresholdIgnored = false;
-        this._dragStartX = beginCoords.x;
-        this._dragStartY = beginCoords.y;
-
-        if (!this._manualMode &&
-            this.state === Clutter.GestureState.POSSIBLE)
-            this._maybeStartDrag(point);
-    }
-
-    vfunc_point_moved(point) {
-        if (!this._manualMode &&
-            this.state === Clutter.GestureState.POSSIBLE)
-            this._maybeStartDrag(point);
-    }
-
-    vfunc_point_ended(point) {
-        if (this.state === Clutter.GestureState.POSSIBLE &&
-            this.get_n_points() === 1) {
-            // All points were removed and we're still in POSSIBLE, this means
-            // we're in manual mode and nobody told us to start the drag.
-            this.set_state(Clutter.GestureState.CANCELLED);
-        }
-    }
-
     _cancelDrag(eventTime) {
         this.emit('drag-cancelled', eventTime);
 
@@ -736,11 +620,10 @@ export const DndGesture = GObject.registerClass({
         });
     }
 
-    vfunc_state_changed(oldState, newState) {
-        if (newState === Clutter.GestureState.COMPLETED)
-            this._gestureRecognized();
+    get startGesture() {
+        return this._dndGesture;
     }
-});
+}
 
 /**
  * Create an object which controls drag and drop for the given actor.
@@ -764,7 +647,5 @@ export const DndGesture = GObject.registerClass({
  * @returns {_Draggable} a new Draggable
  */
 export function makeDraggable(actor, params) {
-    const dndGesture = new DndGesture(params);
-    actor.add_action(dndGesture);
-    return dndGesture;
+    return new _Draggable(actor, params);
 }
