@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
@@ -75,7 +73,7 @@ class BaseIcon extends St.BoxLayout {
 
         super._init({
             style_class: styleClass,
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
         });
 
         this.iconSize = ICON_SIZE;
@@ -269,65 +267,63 @@ function swap(value, length) {
 export const IconGridLayout = GObject.registerClass({
     Properties: {
         'allow-incomplete-pages': GObject.ParamSpec.boolean('allow-incomplete-pages',
-            'Allow incomplete pages', 'Allow incomplete pages',
+            null, null,
             GObject.ParamFlags.READWRITE,
             true),
         'column-spacing': GObject.ParamSpec.int('column-spacing',
-            'Column spacing', 'Column spacing',
+            null, null,
             GObject.ParamFlags.READWRITE,
             0, GLib.MAXINT32, 0),
         'columns-per-page': GObject.ParamSpec.int('columns-per-page',
-            'Columns per page', 'Columns per page',
+            null, null,
             GObject.ParamFlags.READWRITE,
             1, GLib.MAXINT32, 6),
         'fixed-icon-size': GObject.ParamSpec.int('fixed-icon-size',
-            'Fixed icon size', 'Fixed icon size',
+            null, null,
             GObject.ParamFlags.READWRITE,
             -1, GLib.MAXINT32, -1),
         'icon-size': GObject.ParamSpec.int('icon-size',
-            'Icon size', 'Icon size',
+            null, null,
             GObject.ParamFlags.READABLE,
             0, GLib.MAXINT32, 0),
         'last-row-align': GObject.ParamSpec.enum('last-row-align',
-            'Last row align', 'Last row align',
+            null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.ActorAlign.$gtype,
             Clutter.ActorAlign.FILL),
         'max-column-spacing': GObject.ParamSpec.int('max-column-spacing',
-            'Maximum column spacing', 'Maximum column spacing',
+            null, null,
             GObject.ParamFlags.READWRITE,
             -1, GLib.MAXINT32, -1),
         'max-row-spacing': GObject.ParamSpec.int('max-row-spacing',
-            'Maximum row spacing', 'Maximum row spacing',
+            null, null,
             GObject.ParamFlags.READWRITE,
             -1, GLib.MAXINT32, -1),
         'orientation': GObject.ParamSpec.enum('orientation',
-            'Orientation', 'Orientation',
+            null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.Orientation.$gtype,
             Clutter.Orientation.VERTICAL),
         'page-halign': GObject.ParamSpec.enum('page-halign',
-            'Horizontal page align',
-            'Horizontal page align',
+            null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.ActorAlign.$gtype,
             Clutter.ActorAlign.FILL),
         'page-padding': GObject.ParamSpec.boxed('page-padding',
-            'Page padding', 'Page padding',
+            null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.Margin.$gtype),
         'page-valign': GObject.ParamSpec.enum('page-valign',
-            'Vertical page align',
-            'Vertical page align',
+            null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.ActorAlign.$gtype,
             Clutter.ActorAlign.FILL),
         'row-spacing': GObject.ParamSpec.int('row-spacing',
-            'Row spacing', 'Row spacing',
+            null, null,
             GObject.ParamFlags.READWRITE,
             0, GLib.MAXINT32, 0),
         'rows-per-page': GObject.ParamSpec.int('rows-per-page',
-            'Rows per page', 'Rows per page',
+            null, null,
             GObject.ParamFlags.READWRITE,
             1, GLib.MAXINT32, 4),
     },
@@ -345,7 +341,7 @@ export const IconGridLayout = GObject.registerClass({
 
         this._iconSize = this.fixedIconSize !== -1
             ? this.fixedIconSize
-            : IconSize.LARGE;
+            : IconSize.MEDIUM;
 
         this._pageSizeChanged = false;
         this._pageHeight = 0;
