@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -41,15 +39,15 @@ function isPopupMetaWindow(actor) {
 export const MonitorConstraint = GObject.registerClass({
     Properties: {
         'primary': GObject.ParamSpec.boolean(
-            'primary', 'Primary', 'Track primary monitor',
+            'primary', null, null,
             GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE,
             false),
         'index': GObject.ParamSpec.int(
-            'index', 'Monitor index', 'Track specific monitor',
+            'index', null, null,
             GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE,
             -1, 64, -1),
         'work-area': GObject.ParamSpec.boolean(
-            'work-area', 'Work-area', 'Track monitor\'s work-area',
+            'work-area', null, null,
             GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE,
             false),
     },
@@ -227,7 +225,7 @@ export const LayoutManager = GObject.registerClass({
 
         // Set up stage hierarchy to group all UI actors under one container.
         this.uiGroup = new UiActor({name: 'uiGroup', reactive: true});
-        this.uiGroup.set_flags(Clutter.ActorFlags.NO_LAYOUT);
+        this.uiGroup.set_no_layout(true);
 
         global.stage.add_child(this.uiGroup);
 
@@ -332,7 +330,7 @@ export const LayoutManager = GObject.registerClass({
 
         this.panelBox = new St.BoxLayout({
             name: 'panelBox',
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
         });
         this.addChrome(this.panelBox, {
             affectsStruts: true,
@@ -848,39 +846,47 @@ export const LayoutManager = GObject.registerClass({
         else
             this.emit('startup-prepared');
 
-        this._startupAnimation();
-    }
-
-    _startupAnimation() {
-        if (Meta.is_restart())
+        try {
+            await this._startupAnimation();
+        } finally {
             this._startupAnimationComplete();
-        else if (Main.sessionMode.isGreeter)
-            this._startupAnimationGreeter();
-        else
-            this._startupAnimationSession();
+        }
     }
 
-    _startupAnimationGreeter() {
-        this.panelBox.ease({
-            translation_y: 0,
-            duration: STARTUP_ANIMATION_TIME,
-            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
-            onStopped: () => this._startupAnimationComplete(),
+    async _startupAnimation() {
+        if (Meta.is_restart())
+            return;
+
+        if (Main.sessionMode.isGreeter)
+            await this._startupAnimationGreeter();
+        else
+            await this._startupAnimationSession();
+    }
+
+    async _startupAnimationGreeter() {
+        await new Promise(resolve => {
+            this.panelBox.ease({
+                translation_y: 0,
+                duration: STARTUP_ANIMATION_TIME,
+                mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+                onStopped: () => resolve(),
+            });
         });
     }
 
-    _startupAnimationSession() {
-        const onStopped = () => this._startupAnimationComplete();
+    async _startupAnimationSession() {
         if (Main.sessionMode.hasOverview) {
-            Main.overview.runStartupAnimation(onStopped);
+            await Main.overview.runStartupAnimation();
         } else {
-            this.uiGroup.ease({
-                scale_x: 1,
-                scale_y: 1,
-                opacity: 255,
-                duration: STARTUP_ANIMATION_TIME,
-                mode: Clutter.AnimationMode.EASE_OUT_QUAD,
-                onStopped,
+            await new Promise(resolve => {
+                this.uiGroup.ease({
+                    scale_x: 1,
+                    scale_y: 1,
+                    opacity: 255,
+                    duration: STARTUP_ANIMATION_TIME,
+                    mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+                    onStopped: () => resolve(),
+                });
             });
         }
     }
@@ -1433,8 +1439,7 @@ class HotCorner extends Clutter.Actor {
     _onCornerLeft(actor, event) {
         if (event.get_related() !== this)
             this._entered = false;
-        // Consume event, otherwise this will confuse onEnvironsLeft
-        return Clutter.EVENT_STOP;
+        return Clutter.EVENT_PROPAGATE;
     }
 
     vfunc_leave_event(event) {
