@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Cogl from 'gi://Cogl';
 import Gio from 'gi://Gio';
@@ -49,6 +47,7 @@ const LG_ANIMATION_TIME = 500;
 
 const SHELL_RUNTIME_DEBUG_FLAGS = {
     'MetaContext unsafe-mode': 'global.context.unsafe_mode',
+    'MetaContext debug-control': 'global.context.get_debug_control().exported',
     'Invert is-phone value': 'Main.layoutManager.forceInvertIsPhone',
 };
 
@@ -143,7 +142,7 @@ const Notebook = GObject.registerClass({
 }, class Notebook extends St.BoxLayout {
     _init() {
         super._init({
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             y_expand: true,
         });
 
@@ -315,7 +314,7 @@ class ObjLink extends St.Button {
 const Result = GObject.registerClass(
 class Result extends St.BoxLayout {
     _init(lookingGlass, command, o, index) {
-        super._init({vertical: true});
+        super._init({orientation: Clutter.Orientation.VERTICAL});
 
         this.index = index;
         this.o = o;
@@ -338,7 +337,10 @@ class Result extends St.BoxLayout {
 const WindowList = GObject.registerClass({
 }, class WindowList extends St.BoxLayout {
     _init(lookingGlass) {
-        super._init({name: 'Windows', vertical: true, style: 'spacing: 8px'});
+        super._init({
+            name: 'LookingGlassWindows',
+            orientation: Clutter.Orientation.VERTICAL,
+        });
         let tracker = Shell.WindowTracker.get_default();
         this._updateId = Main.initializeDeferredWork(this, this._updateWindowList.bind(this));
         global.display.connect('window-created', this._updateWindowList.bind(this));
@@ -361,17 +363,31 @@ const WindowList = GObject.registerClass({
                 metaWindow.connect('unmanaged', this._updateWindowList.bind(this));
                 metaWindow._lookingGlassManaged = true;
             }
-            let box = new St.BoxLayout({vertical: true});
+            const box = new St.BoxLayout({
+                orientation: Clutter.Orientation.VERTICAL,
+                style_class: 'lg-window',
+            });
             this.add_child(box);
+
+            const header = new St.BoxLayout({
+                orientation: Clutter.Orientation.VERTICAL,
+                style_class: 'lg-window-name',
+            });
+            box.add_child(header);
+
             let windowLink = new ObjLink(this._lookingGlass, metaWindow, metaWindow.title);
-            box.add_child(windowLink);
-            let propsBox = new St.BoxLayout({vertical: true, style: 'padding-left: 6px;'});
+            header.add_child(windowLink);
+
+            const propsBox = new St.BoxLayout({
+                orientation: Clutter.Orientation.VERTICAL,
+                style_class: 'lg-window-props-box',
+            });
             box.add_child(propsBox);
             propsBox.add_child(new St.Label({text: `wmclass: ${metaWindow.get_wm_class()}`}));
             let app = tracker.get_window_app(metaWindow);
             if (app != null && !app.is_window_backed()) {
                 let icon = app.create_icon_texture(22);
-                let propBox = new St.BoxLayout({style: 'spacing: 6px; '});
+                let propBox = new St.BoxLayout({style_class: 'lg-window-props'});
                 propsBox.add_child(propBox);
                 propBox.add_child(new St.Label({text: 'app: '}));
                 let appLink = new ObjLink(this._lookingGlass, app, app.get_id());
@@ -392,6 +408,8 @@ const ObjInspector = GObject.registerClass(
 class ObjInspector extends St.ScrollView {
     _init(lookingGlass) {
         super._init({
+            name: 'LookingGlassPropertyInspector',
+            style_class: 'lg-dialog',
             pivot_point: new Graphene.Point({x: 0.5, y: 0.5}),
         });
 
@@ -401,9 +419,7 @@ class ObjInspector extends St.ScrollView {
         this._parentList = [];
 
         this._container = new St.BoxLayout({
-            name: 'LookingGlassPropertyInspector',
-            style_class: 'lg-dialog',
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             x_expand: true,
             y_expand: true,
         });
@@ -440,7 +456,7 @@ class ObjInspector extends St.ScrollView {
         }
 
         button = new St.Button({
-            style_class: 'window-close',
+            style_class: 'lg-obj-inspector-close-button',
             icon_name: 'window-close-symbolic',
         });
         button.connect('clicked', this.close.bind(this));
@@ -591,7 +607,7 @@ export const Inspector = GObject.registerClass({
 
         const eventHandler = new St.BoxLayout({
             name: 'LookingGlassDialog',
-            vertical: false,
+            orientation: Clutter.Orientation.HORIZONTAL,
             reactive: true,
         });
         this._eventHandler = eventHandler;
@@ -721,7 +737,10 @@ export const Inspector = GObject.registerClass({
 const Extensions = GObject.registerClass({
 }, class Extensions extends St.BoxLayout {
     _init(lookingGlass) {
-        super._init({vertical: true, name: 'lookingGlassExtensions'});
+        super._init({
+            orientation: Clutter.Orientation.VERTICAL,
+            name: 'LookingGlassExtensions',
+        });
 
         this._lookingGlass = lookingGlass;
         this._noExtensions = new St.Label({
@@ -730,7 +749,7 @@ const Extensions = GObject.registerClass({
         });
         this._numExtensions = 0;
         this._extensionsList = new St.BoxLayout({
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             style_class: 'lg-extensions-list',
         });
         this._extensionsList.add_child(this._noExtensions);
@@ -781,13 +800,15 @@ const Extensions = GObject.registerClass({
 
         if (shouldShow) {
             let errors = extension.errors;
-            let errorDisplay = new St.BoxLayout({vertical: true});
+            const errorDisplay = new St.BoxLayout({
+                orientation: Clutter.Orientation.VERTICAL,
+            });
             if (errors && errors.length) {
                 for (let i = 0; i < errors.length; i++)
                     errorDisplay.add_child(new St.Label({text: errors[i]}));
             } else {
                 /* Translators: argument is an extension UUID. */
-                let message = _('%s has not emitted any errors.').format(extension.uuid);
+                let message = _('%s has not emitted any errors').format(extension.uuid);
                 errorDisplay.add_child(new St.Label({text: message}));
             }
 
@@ -825,7 +846,10 @@ const Extensions = GObject.registerClass({
     }
 
     _createExtensionDisplay(extension) {
-        let box = new St.BoxLayout({style_class: 'lg-extension', vertical: true});
+        const box = new St.BoxLayout({
+            style_class: 'lg-extension',
+            orientation: Clutter.Orientation.VERTICAL,
+        });
         box._extension = extension;
         let name = new St.Label({
             style_class: 'lg-extension-name',
@@ -895,7 +919,7 @@ const ActorLink = GObject.registerClass({
     _init(actor) {
         this._arrow = new St.Icon({
             icon_name: 'pan-end-symbolic',
-            icon_size: 8,
+            icon_size: 12,
             x_align: Clutter.ActorAlign.CENTER,
             y_align: Clutter.ActorAlign.CENTER,
             pivot_point: new Graphene.Point({x: 0.5, y: 0.5}),
@@ -943,7 +967,7 @@ const ActorLink = GObject.registerClass({
 const ActorTreeViewer = GObject.registerClass(
 class ActorTreeViewer extends St.BoxLayout {
     _init(lookingGlass) {
-        super._init();
+        super._init({name: 'LookingGlassActors'});
 
         this._lookingGlass = lookingGlass;
         this._actorData = new Map();
@@ -1005,9 +1029,11 @@ class ActorTreeViewer extends St.BoxLayout {
             this._lookingGlass.inspectObject(actor, button);
         });
 
-        const mainContainer = new St.BoxLayout({vertical: true});
+        const mainContainer = new St.BoxLayout({
+            orientation: Clutter.Orientation.VERTICAL,
+        });
         const childrenContainer = new St.BoxLayout({
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             style: 'padding: 0 0 0 18px',
         });
 
@@ -1142,7 +1168,7 @@ class ClutterDebugFlag extends DebugFlag {
     }
 
     _isEnabled() {
-        const enabledFlags = Meta.get_clutter_debug_flags();
+        const enabledFlags = Clutter.get_debug_flags();
         return !!(enabledFlags[this._argPos] & this._enumValue);
     }
 
@@ -1153,11 +1179,11 @@ class ClutterDebugFlag extends DebugFlag {
     }
 
     _enable() {
-        Meta.add_clutter_debug_flags(...this._getArgs());
+        Clutter.add_debug_flags(...this._getArgs());
     }
 
     _disable() {
-        Meta.remove_clutter_debug_flags(...this._getArgs());
+        Clutter.remove_debug_flags(...this._getArgs());
     }
 });
 
@@ -1227,8 +1253,8 @@ const DebugFlags = GObject.registerClass(
 class DebugFlags extends St.BoxLayout {
     _init() {
         super._init({
-            name: 'lookingGlassDebugFlags',
-            vertical: true,
+            name: 'LookingGlassDebugFlags',
+            orientation: Clutter.Orientation.VERTICAL,
             x_align: Clutter.ActorAlign.CENTER,
         });
 
@@ -1287,7 +1313,7 @@ class LookingGlass extends St.BoxLayout {
         super._init({
             name: 'LookingGlassDialog',
             style_class: 'lg-dialog',
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             visible: false,
             reactive: true,
         });
@@ -1303,11 +1329,6 @@ class LookingGlass extends St.BoxLayout {
         // Sort of magic, but...eh.
         this._maxItems = 150;
 
-        this._interfaceSettings = new Gio.Settings({schema_id: 'org.gnome.desktop.interface'});
-        this._interfaceSettings.connect('changed::monospace-font-name',
-            this._updateFont.bind(this));
-        this._updateFont();
-
         // We want it to appear to slide out from underneath the panel
         Main.uiGroup.add_child(this);
         Main.uiGroup.set_child_below_sibling(this,
@@ -1369,12 +1390,15 @@ class LookingGlass extends St.BoxLayout {
         toolbar.add_child(emptyBox);
         toolbar.add_child(notebook.tabControls);
 
-        this._evalBox = new St.BoxLayout({name: 'EvalBox', vertical: true});
+        this._evalBox = new St.BoxLayout({
+            name: 'LookingGlassEvaluator',
+            orientation: Clutter.Orientation.VERTICAL,
+        });
         notebook.appendPage('Evaluator', this._evalBox);
 
         this._resultsArea = new St.BoxLayout({
-            name: 'ResultsArea',
-            vertical: true,
+            style_class: 'evaluator-results',
+            orientation: Clutter.Orientation.VERTICAL,
             y_expand: true,
         });
         this._evalBox.add_child(this._resultsArea);
@@ -1447,25 +1471,6 @@ class LookingGlass extends St.BoxLayout {
         }
     }
 
-    vfunc_captured_event(event) {
-        if (Main.screenShield.maybeHandleEvent(event))
-            return Clutter.EVENT_PROPAGATE;
-
-        return Clutter.EVENT_PROPAGATE;
-    }
-
-    _updateFont() {
-        let fontName = this._interfaceSettings.get_string('monospace-font-name');
-        let fontDesc = Pango.FontDescription.from_string(fontName);
-        // We ignore everything but size and style; you'd be crazy to set your system-wide
-        // monospace font to be bold/oblique/etc. Could easily be added here.
-        let size = fontDesc.get_size() / 1024.;
-        let unit = fontDesc.get_size_is_absolute() ? 'px' : 'pt';
-        this.style = `
-            font-size: ${size}${unit};
-            font-family: "${fontDesc.get_family()}";`;
-    }
-
     setBorderPaintTarget(obj) {
         if (this._borderPaintTarget != null)
             this._borderPaintTarget.remove_effect(this._redBorderEffect);
