@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import GLib from 'gi://GLib';
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
@@ -21,7 +19,10 @@ import * as WorkspaceThumbnail from './workspaceThumbnail.js';
 import * as WorkspacesView from './workspacesView.js';
 
 export const SMALL_WORKSPACE_RATIO = 0.25;
-const DASH_MAX_HEIGHT_RATIO = 0.15;
+const DASH_MAX_HEIGHT_RATIO = 0.16;
+const VERTICAL_SPACING_RATIO = 0.02;
+const THUMBNAILS_SPACING_ADJUSTMENT_TOP = 0.6;
+const THUMBNAILS_SPACING_ADJUSTMENT_BOTTOM = 0.4;
 
 const A11Y_SCHEMA = 'org.gnome.desktop.a11y.keyboard';
 
@@ -49,8 +50,6 @@ class ControlsManagerLayout extends Clutter.LayoutManager {
         this._dash = dash;
         this._background = background;
 
-        this._spacing = 0;
-
         this._cachedWorkspaceBoxes = new Map();
         this._postAllocationCallbacks = [];
 
@@ -115,13 +114,13 @@ this.empty = false;
                 break;
             case ControlsState.WINDOW_PICKER:
                 workspaceBox.set_origin(0,
-                    startY + searchHeight + spacing +
-                    (thumbnailsHeight + spacing) * expandFraction);
+                    startY + searchHeight + Math.round(spacing * THUMBNAILS_SPACING_ADJUSTMENT_TOP) +
+                    thumbnailsHeight + Math.round(spacing * THUMBNAILS_SPACING_ADJUSTMENT_BOTTOM) * expandFraction);
                 workspaceBox.set_size(width,
                     height -
                     (dashHeight > 0 ? dashHeight + spacing : 0) -
-                    searchHeight - spacing -
-                    (thumbnailsHeight + spacing) * expandFraction);
+                    searchHeight - Math.round(spacing * THUMBNAILS_SPACING_ADJUSTMENT_TOP) -
+                    thumbnailsHeight - Math.round(spacing * THUMBNAILS_SPACING_ADJUSTMENT_BOTTOM) * expandFraction);
                 break;
             case ControlsState.APP_GRID:
                 workspaceBox.set_origin(0, startY + searchHeight + spacing);
@@ -197,20 +196,6 @@ else
         this._postAllocationCallbacks = [];
     }
 
-    vfunc_set_container(container) {
-        this._container?.disconnectObject(this);
-        this._container = container;
-        this._container?.connectObject('style-changed',
-            () => {
-                const node = this._container.get_theme_node();
-                const spacing = node.get_length('spacing');
-                if (this._spacing !== spacing) {
-                    this._spacing = spacing;
-                    this.layout_changed();
-                }
-            }, this);
-    }
-
     vfunc_get_preferred_width(_container, _forHeight) {
         // The MonitorConstraint will allocate us a fixed size anyway
         return [0, 0];
@@ -227,7 +212,7 @@ else
         const startY = this._workAreaBox.y1;
         box.y1 += startY;
         const [width, height] = box.get_size();
-        const spacing = height * 0.02;
+        const spacing = Math.round(height * VERTICAL_SPACING_RATIO);
         let availableHeight = height;
 
         // Search entry
@@ -277,7 +262,7 @@ else
             thumbnailsHeight = Math.min(
                 thumbnailsHeight * expandFraction,
                 height * this._workspacesThumbnails.maxThumbnailScale);
-            childBox.set_origin(0, startY + searchHeight + spacing);
+            childBox.set_origin(0, startY + searchHeight + Math.round(spacing * THUMBNAILS_SPACING_ADJUSTMENT_TOP));
             childBox.set_size(width, thumbnailsHeight);
             this._workspacesThumbnails.allocate(childBox);
         }
@@ -372,7 +357,7 @@ else
 export const OverviewAdjustment = GObject.registerClass({
     Properties: {
         'gesture-in-progress': GObject.ParamSpec.boolean(
-            'gesture-in-progress', 'Gesture in progress', 'Gesture in progress',
+            'gesture-in-progress', null, null,
             GObject.ParamFlags.READWRITE,
             false),
     },
@@ -645,16 +630,7 @@ class ControlsManager extends St.Widget {
     }
 
     _getFitModeForState(state) {
-            return WorkspacesView.FitMode.SINGLE;
-        switch (state) {
-        case ControlsState.HIDDEN:
-        case ControlsState.WINDOW_PICKER:
-            return WorkspacesView.FitMode.SINGLE;
-        case ControlsState.APP_GRID:
-            return WorkspacesView.FitMode.ALL;
-        default:
-            return WorkspacesView.FitMode.SINGLE;
-        }
+        return WorkspacesView.FitMode.SINGLE;
     }
 
     _getThumbnailsBoxParams() {
@@ -712,7 +688,12 @@ class ControlsManager extends St.Widget {
             opacity: searchActive ? 0 : opacity,
             duration: animate ? SIDE_CONTROLS_ANIMATION_TIME : 0,
             mode: Clutter.AnimationMode.EASE_OUT_QUAD,
-            onComplete: () => (this._thumbnailsBox.visible = thumbnailsBoxVisible),
+            onComplete: () => {
+                this._thumbnailsBox.set({
+                    visible: thumbnailsBoxVisible,
+                    expandFraction: thumbnailsBoxVisible ? 1.0 : 0.0,
+                });
+            },
         };
 
         if (!searchActive) {
@@ -1026,7 +1007,7 @@ class ControlsManager extends St.Widget {
         }
     }
 
-    async runStartupAnimation(callback) {
+    async runStartupAnimation() {
         this._ignoreShowAppsButtonToggle = true;
 
         this.prepareToEnterOverview();
@@ -1071,14 +1052,16 @@ class ControlsManager extends St.Widget {
         });
 
         // The Dash rises from the bottom. This is the last animation to finish,
-        // so run the callback there.
+        // so resolve the promise there.
         this.dash.translation_y = this.dash.height + this.dash.margin_bottom;
-        this.dash.ease({
-            translation_y: 0,
-            delay: STARTUP_ANIMATION_TIME,
-            duration: STARTUP_ANIMATION_TIME,
-            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
-            onComplete: () => callback(),
+        return new Promise(resolve => {
+            this.dash.ease({
+                translation_y: 0,
+                delay: STARTUP_ANIMATION_TIME,
+                duration: STARTUP_ANIMATION_TIME,
+                mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+                onStopped: () => resolve(),
+            });
         });
     }
 
