@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Atk from 'gi://Atk';
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
@@ -10,10 +8,12 @@ import Polkit from 'gi://Polkit';
 import Shell from 'gi://Shell';
 import St from 'gi://St';
 
+import * as Config from '../../misc/config.js';
 import * as Main from '../main.js';
 import * as PopupMenu from '../popupMenu.js';
 import * as MessageTray from '../messageTray.js';
 import * as ModemManager from '../../misc/modemManager.js';
+import * as Signals from '../../misc/signals.js';
 import * as Util from '../../misc/util.js';
 
 import {Spinner} from '../animation.js';
@@ -159,16 +159,16 @@ class ItemSorter {
 
 const NMMenuItem = GObject.registerClass({
     Properties: {
-        'radio-mode': GObject.ParamSpec.boolean('radio-mode', '', '',
+        'radio-mode': GObject.ParamSpec.boolean('radio-mode', null, null,
             GObject.ParamFlags.READWRITE,
             false),
-        'is-active': GObject.ParamSpec.boolean('is-active', '', '',
+        'is-active': GObject.ParamSpec.boolean('is-active', null, null,
             GObject.ParamFlags.READABLE,
             false),
-        'name': GObject.ParamSpec.string('name', '', '',
+        'name': GObject.ParamSpec.string('name', null, null,
             GObject.ParamFlags.READWRITE,
             ''),
-        'icon-name': GObject.ParamSpec.string('icon-name', '', '',
+        'icon-name': GObject.ParamSpec.string('icon-name', null, null,
             GObject.ParamFlags.READWRITE,
             ''),
     },
@@ -219,7 +219,7 @@ const NMMenuItem = GObject.registerClass({
  */
 const NMSectionItem = GObject.registerClass({
     Properties: {
-        'use-submenu': GObject.ParamSpec.boolean('use-submenu', '', '',
+        'use-submenu': GObject.ParamSpec.boolean('use-submenu', null, null,
             GObject.ParamFlags.READWRITE,
             false),
     },
@@ -398,7 +398,7 @@ class NMConnectionItem extends NMMenuItem {
 
 const NMDeviceConnectionItem = GObject.registerClass({
     Properties: {
-        'device-name': GObject.ParamSpec.string('device-name', '', '',
+        'device-name': GObject.ParamSpec.string('device-name', null, null,
             GObject.ParamFlags.READWRITE,
             ''),
     },
@@ -421,7 +421,7 @@ const NMDeviceConnectionItem = GObject.registerClass({
 
 const NMDeviceItem = GObject.registerClass({
     Properties: {
-        'single-device-mode': GObject.ParamSpec.boolean('single-device-mode', '', '',
+        'single-device-mode': GObject.ParamSpec.boolean('single-device-mode', null, null,
             GObject.ParamFlags.READWRITE,
             false),
     },
@@ -766,23 +766,23 @@ class NMBluetoothDeviceItem extends NMDeviceItem {
 const WirelessNetwork = GObject.registerClass({
     Properties: {
         'name': GObject.ParamSpec.string(
-            'name', '', '',
+            'name', null, null,
             GObject.ParamFlags.READABLE,
             ''),
         'icon-name': GObject.ParamSpec.string(
-            'icon-name', '', '',
+            'icon-name', null, null,
             GObject.ParamFlags.READABLE,
             ''),
         'secure': GObject.ParamSpec.boolean(
-            'secure', '', '',
+            'secure', null, null,
             GObject.ParamFlags.READABLE,
             false),
         'is-active': GObject.ParamSpec.boolean(
-            'is-active', '', '',
+            'is-active', null, null,
             GObject.ParamFlags.READABLE,
             false),
         'signal-strength': GObject.ParamSpec.uint(
-            'signal-strength', '', '',
+            'signal-strength', null, null,
             GObject.ParamFlags.READABLE,
             0),
     },
@@ -965,8 +965,8 @@ const WirelessNetwork = GObject.registerClass({
 
     canAutoconnect() {
         const canAutoconnect =
-            this._securityTypes !== NM.UtilsSecurityType.WPA_ENTERPRISE &&
-            this._securityTypes !== NM.UtilsSecurityType.WPA2_ENTERPRISE;
+            this._securityType !== NM.UtilsSecurityType.WPA_ENTERPRISE &&
+            this._securityType !== NM.UtilsSecurityType.WPA2_ENTERPRISE;
         return canAutoconnect;
     }
 
@@ -980,6 +980,15 @@ const WirelessNetwork = GObject.registerClass({
                 this._getDeviceDBusPath(), ap.get_path());
         } else {
             conn = new NM.SimpleConnection();
+            const permission = Polkit.Permission.new_sync('org.freedesktop.NetworkManager.settings.modify.system', null, null);
+            let allowedToShare = false;
+            if (permission)
+                allowedToShare = permission.get_allowed();
+            if (!allowedToShare) {
+                const setting = new NM.SettingConnection();
+                setting.add_permission('user', GLib.get_user_name(), null);
+                conn.add_setting(setting);
+            }
             this._device.client.add_and_activate_connection_async(
                 conn, this._device, ap.get_path(), null, null);
         }
@@ -1087,10 +1096,10 @@ class NMWirelessNetworkItem extends PopupMenu.PopupBaseMenuItem {
 
 const NMWirelessDeviceItem = GObject.registerClass({
     Properties: {
-        'is-hotspot': GObject.ParamSpec.boolean('is-hotspot', '', '',
+        'is-hotspot': GObject.ParamSpec.boolean('is-hotspot', null, null,
             GObject.ParamFlags.READABLE,
             false),
-        'single-device-mode': GObject.ParamSpec.boolean('single-device-mode', '', '',
+        'single-device-mode': GObject.ParamSpec.boolean('single-device-mode', null, null,
             GObject.ParamFlags.READWRITE,
             false),
     },
@@ -1983,12 +1992,118 @@ class NMModemToggle extends NMDeviceToggle {
     }
 });
 
+class CaptivePortalHandler extends Signals.EventEmitter {
+    constructor(checkUri) {
+        super();
+
+        this._checkUri = checkUri;
+        this._connectivityQueue = new Set();
+        this._notifications = new Map();
+        this._portalHelperProxy = null;
+    }
+
+    addConnection(name, path) {
+        if (this._connectivityQueue.has(path) || this._notifications.has(path))
+            return;
+
+        const source = MessageTray.getSystemSource();
+
+        const notification = new MessageTray.Notification({
+            title: _('Sign Into Wi–Fi Network'),
+            body: name,
+            source,
+        });
+        notification.connect('activated',
+            () => this._onNotificationActivated(path));
+        notification.connect('destroy',
+            () => this._notifications.delete(path));
+        this._notifications.set(path, notification);
+        source.addNotification(notification);
+    }
+
+
+    removeConnection(path) {
+        if (this._connectivityQueue.delete(path))
+            this._portalHelperProxy?.CloseAsync(path);
+        this._notifications.get(path)?.destroy(
+            MessageTray.NotificationDestroyedReason.SOURCE_CLOSED);
+        this._notifications.delete(path);
+    }
+
+    _onNotificationActivated(path) {
+        const context = global.create_app_launch_context(
+            global.get_current_time(), -1);
+
+        if (Config.HAVE_PORTAL_HELPER)
+            this._launchPortalHelper(path, context).catch(logError);
+        else
+            Gio.AppInfo.launch_default_for_uri(this._checkUri, context);
+
+        Main.overview.hide();
+        Main.panel.closeCalendar();
+    }
+
+    _portalHelperDone(parameters) {
+        const [path, result] = parameters;
+
+        if (result === PortalHelperResult.CANCELLED) {
+            // Keep the connection in the queue, so the user is not
+            // spammed with more logins until we next flush the queue,
+            // which will happen once they choose a better connection
+            // or we get to full connectivity through other means
+        } else if (result === PortalHelperResult.COMPLETED) {
+            this.removeConnection(path);
+        } else if (result === PortalHelperResult.RECHECK) {
+            this.emit('recheck', path);
+        } else {
+            log(`Invalid result from portal helper: ${result}`);
+        }
+    }
+
+    async _launchPortalHelper(path, context) {
+        if (!this._portalHelperProxy) {
+            this._portalHelperProxy = new Gio.DBusProxy({
+                g_connection: Gio.DBus.session,
+                g_name: 'org.gnome.Shell.PortalHelper',
+                g_object_path: '/org/gnome/Shell/PortalHelper',
+                g_interface_name: PortalHelperInfo.name,
+                g_interface_info: PortalHelperInfo,
+            });
+            this._portalHelperProxy.connectSignal('Done',
+                (proxy, emitter, params) => {
+                    this._portalHelperDone(params);
+                });
+
+            try {
+                await this._portalHelperProxy.init_async(
+                    GLib.PRIORITY_DEFAULT, null);
+            } catch (e) {
+                console.error(`Error launching the portal helper: ${e.message}`);
+            }
+        }
+
+        const {timestamp} = context;
+        this._portalHelperProxy?.AuthenticateAsync(path, this._checkUri, timestamp).catch(logError);
+        this._connectivityQueue.add(path);
+    }
+
+    clear() {
+        for (const item of this._connectivityQueue)
+            this._portalHelperProxy?.CloseAsync(item);
+        this._connectivityQueue.clear();
+
+        for (const n of this._notifications.values())
+            n.destroy(MessageTray.NotificationDestroyedReason.SOURCE_CLOSED);
+        this._notifications.clear();
+    }
+}
+
 export const Indicator = GObject.registerClass(
 class Indicator extends SystemIndicator {
     _init() {
         super._init();
 
-        this._connectivityQueue = new Set();
+        this._portalHandler = null;
 
         this._mainConnection = null;
 
@@ -2054,6 +2169,16 @@ class Indicator extends SystemIndicator {
             this, 'visible',
             GObject.BindingFlags.SYNC_CREATE);
 
+        const {connectivityCheckUri} = this._client;
+        this._portalHandler = new CaptivePortalHandler(connectivityCheckUri);
+        this._portalHandler.connect('recheck', async (o, path) => {
+            try {
+                const state = await this._client.check_connectivity_async(null);
+                if (state >= NM.ConnectivityState.FULL)
+                    this._portalHandler.removeConnection(path);
+            } catch (e) { }
+        });
+
         this._client.connectObject(
             'notify::primary-connection', () => this._syncMainConnection(),
             'notify::activating-connection', () => this._syncMainConnection(),
@@ -2116,42 +2241,10 @@ class Indicator extends SystemIndicator {
             this._notification?.destroy();
     }
 
-    _flushConnectivityQueue() {
-        for (let item of this._connectivityQueue)
-            this._portalHelperProxy?.CloseAsync(item);
-        this._connectivityQueue.clear();
-    }
-
-    _closeConnectivityCheck(path) {
-        if (this._connectivityQueue.delete(path))
-            this._portalHelperProxy?.CloseAsync(path);
-    }
-
-    async _portalHelperDone(parameters) {
-        let [path, result] = parameters;
-
-        if (result === PortalHelperResult.CANCELLED) {
-            // Keep the connection in the queue, so the user is not
-            // spammed with more logins until we next flush the queue,
-            // which will happen once they choose a better connection
-            // or we get to full connectivity through other means
-        } else if (result === PortalHelperResult.COMPLETED) {
-            this._closeConnectivityCheck(path);
-        } else if (result === PortalHelperResult.RECHECK) {
-            try {
-                const state = await this._client.check_connectivity_async(null);
-                if (state >= NM.ConnectivityState.FULL)
-                    this._closeConnectivityCheck(path);
-            } catch (e) { }
-        } else {
-            log(`Invalid result from portal helper: ${result}`);
-        }
-    }
-
-    async _syncConnectivity() {
+    _syncConnectivity() {
         if (this._mainConnection == null ||
             this._mainConnection.state !== NM.ActiveConnectionState.ACTIVATED) {
-            this._flushConnectivityQueue();
+            this._portalHandler.clear();
             return;
         }
 
@@ -2166,35 +2259,9 @@ class Indicator extends SystemIndicator {
         if (!isPortal || Main.sessionMode.isGreeter)
             return;
 
-        let path = this._mainConnection.get_path();
-        if (this._connectivityQueue.has(path))
-            return;
-
-        let timestamp = global.get_current_time();
-        if (!this._portalHelperProxy) {
-            this._portalHelperProxy = new Gio.DBusProxy({
-                g_connection: Gio.DBus.session,
-                g_name: 'org.gnome.Shell.PortalHelper',
-                g_object_path: '/org/gnome/Shell/PortalHelper',
-                g_interface_name: PortalHelperInfo.name,
-                g_interface_info: PortalHelperInfo,
-            });
-            this._portalHelperProxy.connectSignal('Done',
-                (proxy, emitter, params) => {
-                    this._portalHelperDone(params).catch(logError);
-                });
-
-            try {
-                await this._portalHelperProxy.init_async(
-                    GLib.PRIORITY_DEFAULT, null);
-            } catch (e) {
-                console.error(`Error launching the portal helper: ${e.message}`);
-            }
-        }
-
-        this._portalHelperProxy?.AuthenticateAsync(path, this._client.connectivity_check_uri, timestamp).catch(logError);
-
-        this._connectivityQueue.add(path);
+        this._portalHandler.addConnection(
+            this._mainConnection.get_id(),
+            this._mainConnection.get_path());
     }
 
     _updateIcon() {
