@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GObject from 'gi://GObject';
@@ -65,23 +63,23 @@ const GESTURE_FINGER_COUNT = 3;
 export const SwipeTracker = GObject.registerClass({
     Properties: {
         'enabled': GObject.ParamSpec.boolean(
-            'enabled', 'enabled', 'enabled',
+            'enabled', null, null,
             GObject.ParamFlags.READWRITE,
             true),
         'orientation': GObject.ParamSpec.enum(
-            'orientation', 'orientation', 'orientation',
+            'orientation', null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.Orientation, Clutter.Orientation.HORIZONTAL),
         'distance': GObject.ParamSpec.double(
-            'distance', 'distance', 'distance',
+            'distance', null, null,
             GObject.ParamFlags.READWRITE,
             0, Infinity, 0),
         'allow-long-swipes': GObject.ParamSpec.boolean(
-            'allow-long-swipes', 'allow-long-swipes', 'allow-long-swipes',
+            'allow-long-swipes', null, null,
             GObject.ParamFlags.READWRITE,
             false),
         'scroll-modifiers': GObject.ParamSpec.flags(
-            'scroll-modifiers', 'scroll-modifiers', 'scroll-modifiers',
+            'scroll-modifiers', null, null,
             GObject.ParamFlags.READWRITE,
             Clutter.ModifierType, 0),
     },
@@ -105,7 +103,7 @@ export const SwipeTracker = GObject.registerClass({
         this.orientation = orientation;
         this._allowedModes = allowedModes;
         this._enabled = true;
-        this._distance = global.screen_height;
+        this._distance = -1;
 
         this._snapPoints = [];
         this._initialProgress = 0;
@@ -144,25 +142,6 @@ export const SwipeTracker = GObject.registerClass({
         // FIXME: we assume ClutterPanGesture can handle touchpad scroll and discrete scroll
         // everywhere here, but there's no scroll event handling in ClutterPanGesture yet
         return false;
-
-        if (!this.enabled || !this._scrollEnabled)
-            return false;
-
-        if (event.type() !== Clutter.EventType.SCROLL)
-            return false;
-
-        if (event.get_scroll_source() !== Clutter.ScrollSource.FINGER &&
-            event.get_source_device().get_device_type() !== Clutter.InputDeviceType.TOUCHPAD_DEVICE)
-            return false;
-
-        if ((this._allowedModes & Main.actionMode) === 0)
-            return false;
-
-        if (this._panGesture.state !== Clutter.GestureState.RECOGNIZING && this.scrollModifiers !== 0 &&
-            (event.get_state() & this.scrollModifiers) === 0)
-            return false;
-
-        return true;
     }
 
     get enabled() {
@@ -232,10 +211,11 @@ export const SwipeTracker = GObject.registerClass({
         return this._findClosestPoint(pos);
     }
 
-    _updatePanGesture(panGesture, deltaX, deltaY, pannedDistance) {
-        let delta = this.orientation === Clutter.Orientation.HORIZONTAL
-            ? -deltaX
-            : -deltaY;
+    _updatePanGesture(panGesture) {
+        const [deltaVec] = panGesture.get_delta_abs();
+        const delta = this.orientation === Clutter.Orientation.HORIZONTAL
+            ? -deltaVec.get_x()
+            : -deltaVec.get_y();
 
         if (this.orientation === Clutter.Orientation.HORIZONTAL &&
             Clutter.get_default_text_direction() === Clutter.TextDirection.RTL)
@@ -248,10 +228,7 @@ export const SwipeTracker = GObject.registerClass({
         const vertical = this.orientation === Clutter.Orientation.VERTICAL;
         const distance = isTouchpad
             ? vertical ? TOUCHPAD_BASE_HEIGHT : TOUCHPAD_BASE_WIDTH
-            : this._distance;
-
-        if (distance === 0)
-            throw new Error();
+            : this._distance > 0 ? this._distance : global.screen_height;
 
         this._progress += delta / distance;
 
@@ -305,7 +282,7 @@ export const SwipeTracker = GObject.registerClass({
         const vertical = this.orientation === Clutter.Orientation.VERTICAL;
         const distance = isTouchpad
             ? vertical ? TOUCHPAD_BASE_HEIGHT : TOUCHPAD_BASE_WIDTH
-            : this._distance;
+            : this._distance > 0 ? this._distance : global.screen_height;
 
         const endProgress = this._getEndProgress(velocity, distance, isTouchpad);
 
@@ -387,7 +364,7 @@ export const SwipeTracker = GObject.registerClass({
     }
 
     _endPanGesture(panGesture) {
-        const velocity = panGesture.get_velocity();
+        const velocity = panGesture.get_velocity_abs();
         const v = this.orientation === Clutter.Orientation.HORIZONTAL
             ? -velocity.get_x()
             : -velocity.get_y();
@@ -435,12 +412,10 @@ export const SwipeTracker = GObject.registerClass({
     }
 
     destroy() {
-/*
         if (this._panGesture) {
-            this._panGesture.actor.remove_action(this._panGesture);
+            this._panGesture.actor?.remove_action(this._panGesture);
             delete this._panGesture;
         }
-*/
     }
 
     make2d(otherSwipeTracker) {
