@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import AccountsService from 'gi://AccountsService';
 import Atk from 'gi://Atk';
 import Clutter from 'gi://Clutter';
@@ -37,7 +35,10 @@ const BLUR_RADIUS = 90;
 const Clock = GObject.registerClass(
 class UnlockDialogClock extends St.BoxLayout {
     _init() {
-        super._init({style_class: 'unlock-dialog-clock', vertical: true});
+        super._init({
+            style_class: 'unlock-dialog-clock',
+            orientation: Clutter.Orientation.VERTICAL,
+        });
 
         this._time = new St.Label({
             style_class: 'unlock-dialog-clock-time',
@@ -83,7 +84,8 @@ class UnlockDialogSwipeHint extends St.Label {
             opacity: 255,//0,
         });
 
-        this._seat = Clutter.get_default_backend().get_default_seat();
+        const backend = this.get_context().get_backend();
+        this._seat = backend.get_default_seat();
         this._seat.connectObject('notify::touch-mode',
             this._updateHint.bind(this), this);
 
@@ -297,13 +299,14 @@ export const UnlockDialog = GObject.registerClass({
 
         this._promptBox = new St.BoxLayout({
             style_class: 'prompt-box',
-            vertical: true,
+            orientation: Clutter.Orientation.VERTICAL,
             y_align: Clutter.ActorAlign.END,
         });
         this._promptBox.set_pivot_point(0.5, 0.5);
         this._stack.add_child(this._promptBox);
 
         this._promptBoxHidden = true;
+        this._promptBoxHeight = 0;
         this._promptBox.connect('notify::size', () => {
             this._promptBoxHeight = this._promptBox.allocation.get_height();
             if (this._promptBoxHidden)
@@ -379,15 +382,7 @@ export const UnlockDialog = GObject.registerClass({
         this.emit('wake-up-screen');
     }
 
-    vfunc_key_press_event(event) {
-
-
-    }
-
     vfunc_captured_event(event) {
-        if (Main.screenShield.maybeHandleEvent(event))
-            return Clutter.EVENT_STOP;
-
         if (event.type() === Clutter.EventType.KEY_PRESS) {
             const keyval = event.get_key_symbol();
             if (keyval === Clutter.KEY_Shift_L ||
