@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GObject from 'gi://GObject';
@@ -219,9 +217,7 @@ export const WorkspacesView = GObject.registerClass({
         const spacing = (availableSpace - workspaceSize * 0.4) * (1 - fitMode);
         const {scaleFactor} = St.ThemeContext.get_for_stage(global.stage);
 
-return 12;
-        return Math.clamp(spacing, WORKSPACE_MIN_SPACING * scaleFactor,
-            WORKSPACE_MAX_SPACING * scaleFactor);
+        return 12;
     }
 
     _getWorkspaceModeForOverviewState(state) {
@@ -268,18 +264,7 @@ return 12;
     }
 
     _getFitModeForState(state) {
-        const {ControlsState} = OverviewControls;
-
-            return FitMode.SINGLE;
-        switch (state) {
-        case ControlsState.HIDDEN:
-        case ControlsState.WINDOW_PICKER:
-            return FitMode.SINGLE;
-        case ControlsState.APP_GRID:
-            return FitMode.ALL;
-        default:
-            return FitMode.SINGLE;
-        }
+        return FitMode.SINGLE;
     }
 
     _getInitialBoxes(box) {
@@ -862,21 +847,19 @@ class WorkspacesDisplay extends St.Widget {
         }
 
 
-let distance;
         const primaryView = this._workspacesViews[this._primaryIndex];
 
-if (primaryView.getActiveWorkspace().allocation.is_initialized()) {
 
         const workspaceTransformedExtents =
             primaryView.getActiveWorkspace().get_transformed_extents();
 
-        distance = global.workspace_manager.layout_rows === -1
+        let distance = global.workspace_manager.layout_rows === -1
             ? workspaceTransformedExtents.size.height
             : workspaceTransformedExtents.size.width;
-} else {
-log("NOT INI");
-distance = Main.layoutManager.primaryMonitor.width;
-}
+
+        // the workspace might not be allocated yet, so fall back to monitor width
+        if (distance === 0)
+            distance = Main.layoutManager.primaryMonitor.width;
 
         for (let i = 0; i < this._workspacesViews.length; i++)
             this._workspacesViews[i].startTouchGesture();
